==> open-xchange-documents-backend_7.8.4.orig.tar.bz2: open-xchange-documents-backend-7.8.4/com.openexchange.office.filter.odf/src/com/openexchange/office/filter/odf/draw/ShapeHelper.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * @author sven.jacobi@open-xchange.com
 */

package com.openexchange.office.filter.odf.draw;

import org.xml.sax.Attributes;

public class ShapeHelper {

    public static Shape getShape(Attributes attributes, String uri, String localName, String qName, boolean rootShape) {
	    switch(qName) {
            case "draw:g": {
                return new GroupShape(attributes, rootShape);
            }
            case "draw:custom-shape": {
                return new CustomShape(attributes, rootShape);
            }
            case "draw:measure":
            case "draw:caption":
            case "draw:circle":
            case "draw:ellipse":
            case "draw:path":
            case "draw:rect":
            case "draw:regular-polygon": {
                return new Shape(attributes, uri, localName, qName, rootShape);
            }
            case "draw:polygon":
            case "draw:polyline": {
                return new Polygon(attributes, uri, localName, qName, rootShape);
            }
            case "draw:connector":
            case "draw:line": {
                return new LineShape(attributes, uri, localName, qName, rootShape);
            }

            case "draw:page-thumbnail":
            case "draw:control":
            case "dr3d:scene": {
                return new UndefinedShape(attributes, uri, localName, qName, rootShape);
            }
            default: {
                return null;
            }
	    }
	}
}

==> open-xchange-documents-backend_7.10.3.orig.tar.bz2: open-xchange-documents-backend-7.10.3/com.openexchange.office.filter.odf/src/com/openexchange/office/filter/odf/draw/ShapeHelper.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * @author sven.jacobi@open-xchange.com
 */

package com.openexchange.office.filter.odf.draw;

import org.xml.sax.Attributes;
import com.openexchange.office.filter.odf.AttributesImpl;

public class ShapeHelper {

    public static Shape getShape(Attributes attributes, String uri, String localName, String qName, GroupShape parentGroup, boolean rootShape, boolean contentStyle) {
	    switch(qName) {
            case "draw:g": {
                return new GroupShape(new AttributesImpl(attributes), parentGroup, rootShape, contentStyle);
            }
            case "draw:custom-shape": {
                return new CustomShape(new AttributesImpl(attributes), parentGroup, rootShape, contentStyle);
            }
            case "draw:circle":
            case "draw:ellipse": {
                return new Ellipse(new AttributesImpl(attributes), uri, localName, qName, parentGroup, rootShape, contentStyle);
            }
            case "draw:measure":
            case "draw:caption":
            case "draw:rect":
            case "draw:regular-polygon": {
                return new Shape(new AttributesImpl(attributes), uri, localName, qName, parentGroup, rootShape, contentStyle);
            }
            case "draw:path": {
                return new Path(new AttributesImpl(attributes), uri, localName, qName, parentGroup, rootShape, contentStyle);
            }
            case "draw:polygon":
            case "draw:polyline": {
                return new Polygon(new AttributesImpl(attributes), uri, localName, qName, parentGroup, rootShape, contentStyle);
            }

            case "draw:connector": {
                return new ConnectorShape(new AttributesImpl(attributes), uri, localName, qName, parentGroup, rootShape, contentStyle);
            }
            case "draw:line": {
                return new LineShape(new AttributesImpl(attributes), uri, localName, qName, parentGroup, rootShape, contentStyle);
            }

            case "draw:page-thumbnail":
            case "draw:control":
            case "dr3d:scene": {
                return new UndefinedShape(new AttributesImpl(attributes), uri, localName, qName, parentGroup, rootShape, contentStyle);
            }
            default: {
                return null;
            }
	    }
	}
}
